==> pyinaturalist-0.15.0dev2-py3-none-any.whl: pyinaturalist/v1/__init__.py <==
"""
Functions to access the iNaturalist API v1
See: http://api.inaturalist.org/v1/docs/

Most recent API version tested: 1.3.0
"""
# flake8: noqa: F401, F403
from requests import Response

from pyinaturalist.api_requests import delete, get, post, put
from pyinaturalist.constants import API_V1_BASE_URL


def get_v1(endpoint: str, **kwargs) -> Response:
    """Make a GET request to iNaturalist API v1"""
    return get(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def post_v1(endpoint: str, **kwargs) -> Response:
    """Make a POST request to iNaturalist API v1"""
    return post(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def put_v1(endpoint: str, **kwargs) -> Response:
    """Make a PUT request to iNaturalist API v1"""
    return put(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def delete_v1(endpoint: str, **kwargs) -> Response:
    """Make a DELETE request to iNaturalist API v1"""
    return delete(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


from pyinaturalist.v1.controlled_terms import get_controlled_terms
from pyinaturalist.v1.identifications import get_identifications, get_identifications_by_id
from pyinaturalist.v1.observations import (
    create_observation,
    delete_observation,
    get_observation,
    get_observation_histogram,
    get_observation_identifiers,
    get_observation_observers,
    get_observation_species_counts,
    get_observation_taxon_summary,
    get_observation_taxonomy,
    get_observations,
    upload,
)
from pyinaturalist.v1.places import get_places_autocomplete, get_places_by_id, get_places_nearby
from pyinaturalist.v1.posts import get_posts
from pyinaturalist.v1.projects import (
    add_project_observation,
    delete_project_observation,
    get_projects,
    get_projects_by_id,
)
from pyinaturalist.v1.search import search
from pyinaturalist.v1.taxa import get_taxa, get_taxa_autocomplete, get_taxa_by_id
from pyinaturalist.v1.users import get_user_by_id, get_users_autocomplete

==> pyinaturalist-0.15.1dev0-py3-none-any.whl: pyinaturalist/v1/__init__.py <==
"""
Functions to access the iNaturalist API v1
See: http://api.inaturalist.org/v1/docs/

Most recent API version tested: 1.3.0
"""
# flake8: noqa: F401, F403
from requests import Response

from pyinaturalist.constants import API_V1_BASE_URL
from pyinaturalist.session import delete, get, post, put


def get_v1(endpoint: str, **kwargs) -> Response:
    """Make a GET request to iNaturalist API v1"""
    return get(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def post_v1(endpoint: str, **kwargs) -> Response:
    """Make a POST request to iNaturalist API v1"""
    return post(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def put_v1(endpoint: str, **kwargs) -> Response:
    """Make a PUT request to iNaturalist API v1"""
    return put(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


def delete_v1(endpoint: str, **kwargs) -> Response:
    """Make a DELETE request to iNaturalist API v1"""
    return delete(f'{API_V1_BASE_URL}/{endpoint}', **kwargs)


from pyinaturalist.v1.controlled_terms import get_controlled_terms
from pyinaturalist.v1.identifications import get_identifications, get_identifications_by_id
from pyinaturalist.v1.observation_fields import delete_observation_field, set_observation_field
from pyinaturalist.v1.observations import (
    create_observation,
    delete_observation,
    get_observation,
    get_observation_histogram,
    get_observation_identifiers,
    get_observation_observers,
    get_observation_species_counts,
    get_observation_taxon_summary,
    get_observation_taxonomy,
    get_observations,
    update_observation,
    upload,
)
from pyinaturalist.v1.places import get_places_autocomplete, get_places_by_id, get_places_nearby
from pyinaturalist.v1.posts import get_posts
from pyinaturalist.v1.projects import (
    add_project_observation,
    delete_project_observation,
    get_projects,
    get_projects_by_id,
)
from pyinaturalist.v1.search import search
from pyinaturalist.v1.taxa import get_taxa, get_taxa_autocomplete, get_taxa_by_id
from pyinaturalist.v1.users import get_user_by_id, get_users_autocomplete
